@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77header.c 10173 2014-01-01 09:52:34Z pwessel $
+ *	$Id: mgd77header.c 10289 2014-12-28 21:17:06Z pwessel $
  *
- *    Copyright (c) 2004-2014 by P. Wessel and Michael Chandler
+ *    Copyright (c) 2004-2015 by P. Wessel and Michael Chandler
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -54,14 +54,16 @@ int main (int argc, char **argv)
     
 	time_t tt;
 	struct tm *tod = NULL;
-	time (&tt);
-	tod = localtime(&tt);
 	
-	char *tvalue[MGD77_MAX_COLS], buffer[BUFSIZ], **list = NULL, name[BUFSIZ], value[BUFSIZ], params[BUFSIZ], hinfile[BUFSIZ], line[BUFSIZ];
+	char *tvalue[MGD77_MAX_COLS], buffer[BUFSIZ], name[BUFSIZ], value[BUFSIZ], params[BUFSIZ], hinfile[BUFSIZ], line[BUFSIZ];
+	char **list = NULL;
 
 	struct MGD77_CONTROL M, Out;
 	struct MGD77_DATASET *D = NULL;
 		
+	time (&tt);
+	tod = localtime(&tt);
+
 	argc = (int)GMT_begin (argc, argv);		/* Initialize GMT Machinery */
 	
 	/* Initialize MGD77 output order and other parameters*/
