@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: ps2raster.c 10202 2014-02-08 16:43:38Z jluis $
+ *	$Id: ps2raster.c 10289 2014-12-28 21:17:06Z pwessel $
  *
- *	Copyright (c) 2006-2014 by J. Luis
+ *	Copyright (c) 2006-2015 by J. Luis
  *	See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -553,7 +553,8 @@ int main (int argc, char **argv) {
 			BB_file = (char *) GMT_memory (VNULL, (size_t)BUFSIZ, sizeof(char), GMT_program);
 			sprintf (BB_file, "%s/ps2raster_%ldc.bb", Ctrl->D.dir, (GMT_LONG)getpid());
 			psfile_to_use = (Ctrl->A.strip) ? no_U_file : ((clean_PS_file) ? clean_PS_file : ps_file);
-			sprintf (cmd, "%s%s %s %s %s 2> %s", at_sign, Ctrl->G.file, gs_BB, gs_extra, psfile_to_use, BB_file);
+			/* sprintf (cmd, "%s%s %s %s %s 2> %s", at_sign, Ctrl->G.file, gs_BB, gs_extra, psfile_to_use, BB_file); */
+			sprintf (cmd, "%s%s %s \'%s\' 2> %s", at_sign, Ctrl->G.file, gs_BB, psfile_to_use, BB_file);
 			sys_retval = system (cmd);		/* Execute the command that computes the tight BB */
 			if (sys_retval) {
 				fprintf (stderr, "%s: System call [%s] returned error %d.\n", GMT_program, cmd, sys_retval);
@@ -576,7 +577,7 @@ int main (int argc, char **argv) {
 						sprintf (tmp_file, "%s/", Ctrl->D.dir);
 						strncat (tmp_file, &ps_file[pos_file], (size_t)(pos_ext - pos_file));
 						strcat (tmp_file, ext[Ctrl->T.device]);
-						sprintf (cmd, "%s%s %s %s -sDEVICE=%s -g1x1 -r%ld -sOutputFile=%s -f%s", 
+						sprintf (cmd, "%s%s %s %s -sDEVICE=%s -g1x1 -r%ld -sOutputFile=\'%s\' -f\'%s\'", 
 							at_sign, Ctrl->G.file, gs_params, gs_extra, device[Ctrl->T.device],
 							Ctrl->E.dpi, tmp_file, ps_file);
 						sys_retval = system (cmd);		/* Execute the GhostScript command */
@@ -861,7 +862,7 @@ int main (int argc, char **argv) {
 			strcat (out_file, ext[Ctrl->T.device]);
 			pix_w = (GMT_LONG)ceil (w * Ctrl->E.dpi / 72.0);
 			pix_h = (GMT_LONG)ceil (h * Ctrl->E.dpi / 72.0);
-			sprintf (cmd, "%s%s %s %s -sDEVICE=%s -g%ldx%ld -r%ld -sOutputFile=%s -f%s", 
+			sprintf (cmd, "%s%s %s %s -sDEVICE=%s -g%ldx%ld -r%ld -sOutputFile=\'%s\' -f\'%s\'", 
 				at_sign, Ctrl->G.file, gs_params, gs_extra, device[Ctrl->T.device],
 				pix_w, pix_h, Ctrl->E.dpi, out_file, tmp_file);
 			sys_retval = system (cmd);		/* Execute the GhostScript command */
@@ -964,10 +965,10 @@ int main (int argc, char **argv) {
 					quiet = "";
 
 #ifdef WIN32
-				sprintf (cmd, "gdal_translate -a_srs \"%s\" -co COMPRESS=LZW -co TILED=YES %s %s %s", 
+				sprintf (cmd, "gdal_translate -a_srs \"%s\" -co COMPRESS=LZW -co TILED=YES %s \'%s\' \'%s\'", 
 						proj4_cmd, quiet, out_file, world_file); 
 #else
-				sprintf (cmd, "gdal_translate -a_srs '%s' -co COMPRESS=LZW -co TILED=YES %s %s %s", 
+				sprintf (cmd, "gdal_translate -a_srs '%s' -co COMPRESS=LZW -co TILED=YES %s \'%s\' \'%s\'", 
 						proj4_cmd, quiet, out_file, world_file); 
 #endif
 				free(proj4_cmd);
